@@ -1,10 +1,11 @@
 package Lingua::JA::Name::Splitter;
-require Exporter;
-@ISA = qw(Exporter);
-@EXPORT_OK = qw/split_kanji_name split_romaji_name/;
 use warnings;
 use strict;
-our $VERSION = 0.07;
+require Exporter;
+our @ISA = qw(Exporter);
+our @EXPORT_OK = qw/split_kanji_name split_romaji_name/;
+our %EXPORT_TAGS = ('all' => \@EXPORT_OK);
+our $VERSION = '0.08';
 use utf8;
 use Carp;
 use Lingua::JA::Moji ':all';
